This package is meant to replicate some of the useful SAS macros used in the Cancer Center to make R more friendly and easier to use.
Below are a list of some of the most useful functions in clinicaltrials.
crtlibn: Load SAS datasets from the project space
accgph: Accrual graph
acc.quarter: Quarterly accrual table
eot.table: End of treatment table for Alliance DSMB report
aerpt.summary: AE summary table for Alliance DSMB report
aerpt.listing: AE listing table for Alliance DSMB report
gre_table: Gender, race, and ethinic inclusion table used in the Alliance DSMB report and CIRB section 2
irbtox_summary: AE summary table for Mayo DSMB report
irbtox_listing: AE listing table for Mayo DSMB report
overduefu: Overdue follow-up table for Alliance DSMB report
survival.table: Table for survival analysis output
forest_plot: Creates a forestplot for survival meta-analysis
km.plot: Creates a publication quality KM plot
tidy_tableby: Creates a nicely formatted tableby() summary when knitting to .docx using flextable
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.